Class: VaeLocal

Inherits:
Object
  • Object
show all
Defined in:
lib/vae_local.rb

Constant Summary collapse

"Vae local preview server, version #{VER}"

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.fetch_from_vaeplatform(site, req) ⇒ Object



4
5
6
7
8
9
10
11
12
13
# File 'lib/vae_local.rb', line 4

def self.fetch_from_vaeplatform(site, req)
  local = ENV['VAEPLATFORM_LOCAL']
  http = Net::HTTP.new("#{site}." + (local ? "vaeplatform.dev" : "vaeplatform.com"), (local ? 80 : 443))
  http.use_ssl = true unless local
  http.verify_mode = OpenSSL::SSL::VERIFY_NONE
  http.start { |http|
    http.read_timeout = 120
    http.request(req)
  }
end

.port_open?(port) ⇒ Boolean

Returns:

  • (Boolean)


15
16
17
# File 'lib/vae_local.rb', line 15

def self.port_open?(port)
  !system("lsof -i:#{port}", out: '/dev/null')
end

.run_trapping_exceptionsObject



120
121
122
123
124
125
126
127
128
129
130
# File 'lib/vae_local.rb', line 120

def self.run_trapping_exceptions
  begin
    new.run
  rescue VaeError => e
    cmd = $0
    cmd = "vae" if cmd =~ /\.\.\/vae_local/
    puts "** Error:"
    puts "   " + e.to_s
    puts "Type #{cmd} --help for help."
  end
end

Instance Method Details

#runObject

Raises:



19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/vae_local.rb', line 19

def run
  options = { port: 9999, server: ProxyServer, log_level: "warning" }
  loop {
    break if VaeLocal.port_open?(options[:port])
    options[:port] = options[:port] - 1
  }

  ARGV.options  do |opts|
    opts.banner = BANNER + "\n\nUsage: vae [options]\n         starts a local development server\n       vae [options] deploy\n         deploys the source in Git repository or provided URL to the Vae servers\n\n  If you are using the Vae Production environment features:\n       vae [options] stage\n         deploys the source in Git repository or provided URL to the staging environment\n       vae [options] stagerelease\n         deploys the source in Git repository or provided URL to the staging environment\n         and releases it to the production environment\n       vae [options] release\n         releases the current staging environment to the production environment\n       vae [options] rollback\n         rolls back the production environment to a previous release\n\nAvailable Options:"
    opts.on("-u","--username <username>","Your Vae username") { |o| options[:username] = o }
    opts.on("-P","--password <password>","Your Vae password") { |o| options[:password] = o }
    opts.on("-p","--port <port number>","Start server on this port") { |o| options[:port] = o.to_i; raise VaeError "Port #{o.to_i} is already in use." unless VaeLocal.port_open?(o.to_i) }
    opts.on("-r","--root <path to site root>","Path to the root of the local copy of your Vae site.") { |o| options[:site_root] = o }
    opts.on("-s","--site <subdomain>","Vae subdomain for this site") { |o| options[:site] = o }
    opts.on("-f","--full-stack [php|hhvm]","Run in Full Stack Mode.  Optionally provide 'php' or 'hhvm' to specify your preferred PHP runtime") { |o| options[:server] = FullStack; options[:php_runtime] = o }
    opts.on("-U","--url <url>","If running stage or stagerelease, provide the URL of a ZIP file to deploy here") { |o| options[:branch] = o }
    opts.on("-b","--branch <branch>","If running stage or stagerelease, override the Git branch to deploy here") { |o| options[:branch] = o }
    opts.on("-d","--data-path <path>","Where to Store Content and Image Data When In Full Stack Mode") { |o| options[:data_path] = o }
    opts.on("-l","--log-level <level>","Vaedb Log Level (for Full Stack Mode)") { |o| options[:log_level] = o }
    opts.on_tail("-h","--help", "Show this help message") { puts opts; exit }
    opts.parse!
  end

  options[:site_root] = Dir.pwd if options[:site_root].nil? and (File.exists?("#{Dir.pwd}/__vae.yml") or File.exists?("#{Dir.pwd}/__verb.yml"))
  if options[:site_root]
    [ "verb", "vae" ].each do |name|
      if File.exists?("#{options[:site_root]}/__#{name}.yml")
        site_conf_file = File.read("#{options[:site_root]}/__#{name}.yml")
        site_conf = YAML.load(site_conf_file)
        options[:site] ||= site_conf[name]["site"] if site_conf[name] and site_conf[name]["site"]
      end
    end
  end

  raise VaeError, "We could not determine the Vae subdomain for this site.  Please specify it manually by using the --site option or create a __vae.yml file within the site root." if options[:site].nil?
  raise VaeError, "We could not determine the Vae username that you use.  Please specify it manually by using the --username option." if options[:username].nil?
  if options[:password].nil?
    options[:password] = ask("Please enter the Vae password for username #{options[:username]}:") { |q| q.echo = false }
  end

  if [ "deploy", "release", "rollback", "stage", "stagerelease" ].include?(ARGV.last)
    stagerelease(ARGV.last, options[:site], options[:username], options[:password], options[:branch])
    exit
  end

  raise VaeError, "You did not specify the path to the root of the local copy of your Vae site.  Please specify it manually by using the --root option or cd to the site root (and make sure it contains a __vae.yml file)." unless options[:site_root]
  raise VaeError, "You specified an invalid path to the local copy of your Vae site." unless File.exists?(options[:site_root])

  Dir.chdir File.dirname(__FILE__)
  puts BANNER

  site = Site.new(subdomain: options[:site], root: options[:site_root], username: options[:username], password: options[:password])
  options[:server].new(site, options).run
  puts "Thanks for using Vae!"
end

#show_job_status(res, site) ⇒ Object



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/vae_local.rb', line 75

def show_job_status(res, site)
  data = JSON.parse(res.body)
  if data['error']
    raise VaeError, data['error']
  else
    puts "Request started, waiting for completion..."
    loop do
      sleep 5
      req = Net::HTTP::Get.new("/api/local/v1/job_status/#{data['job']}")
      res = VaeLocal.fetch_from_vaeplatform(site, req)
      status = JSON.parse(res.body)
      if status['status'] == "completed"
        if status['error'] and status['error'].size > 0
          raise VaeError, "Got the following error from Vae Platform: #{status['error']}"
        else
          puts status['notice']
        end
        return
      elsif status['status'] != "working"
        raise VaeError, "Got the following error from Vae Platform: #{status['error']}"
      end
    end
  end
rescue JSON::ParserError
  raise VaeError, "An unknown error occurred requesting this operation from Vae Platform.  Please email support for help."
end

#stagerelease(action, site, username, password, branch) ⇒ Object



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/vae_local.rb', line 102

def stagerelease(action, site, username, password, branch)
  if action == "deploy"
    action = "stage"
  elsif action == "stagerelease"
    stagerelease("stage", site, username, password, branch)
    stagerelease("release", site, username, password, branch)
    return
  end
  req = Net::HTTP::Post.new("/api/local/v1/#{action}")
  req.body = "username=#{CGI.escape(username)}&password=#{CGI.escape(password)}&branch=#{CGI.escape(branch || "")}&vae_local=1"
  res = VaeLocal.fetch_from_vaeplatform(site, req)
  if res.is_a?(Net::HTTPFound)
    raise VaeError, "Invalid username/password or insufficient permissions."
  else
    show_job_status(res, site)
  end
end